@@ -5,7 +5,7 @@ use Mojo::DOM;
 use Mojo::ByteStream 'b';
 use Mojo::Util qw/secure_compare hmac_sha1_sum/;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 # Todo:
 # - Make everything async (top priority)
@@ -202,7 +202,7 @@ sub verify {
   };
 
   # Not found
-  return $c->render_not_found;
+  return $c->reply->not_found;
 };
 
 
@@ -1089,7 +1089,7 @@ Returns a true value on success.
   # In Controllers
   if ($c->pubsub_subscribe(
     topic => 'https://sojolicio.us/feed.atom',
-    hub   => 'https://hub.sojolicio.us' );
+    hub   => 'https://hub.sojolicio.us',
     lease_seconds => 123456
   )) {
     print 'You successfully subscribed!';
@@ -1347,7 +1347,7 @@ This plugin is part of the L<Sojolicious|http://sojolicio.us> project.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2014, L<Nils Diewald|http://nils-diewald.de/>.
+Copyright (C) 2011-2015, L<Nils Diewald|http://nils-diewald.de/>.
 
 This program is free software, you can redistribute it
 and/or modify it under the terms of the Artistic License version 2.0.
